import { useState, useMemo, useCallback, useEffect } from 'react';
import useDataLoader from './useDataLoader.js';

const usePaginatedDataLoader = function (key, method) {
  let {
    enabled = true,
    initialData,
    keepPreviousData = true,
    onError,
    onSuccess,
    pollingInterval,
    dataLifetime,
    needPolling,
    initialPage,
    perPage = 1
  } = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  const [data, setData] = useState({});
  const [page, setPage] = useState(initialPage ?? 1);
  const keyPage = useMemo(() => [key, ['page', page]].flat(), [key, page]);
  const pageMethod = useCallback(() => method({
    page,
    perPage
  }), [method, page, perPage]);
  const {
    data: pageData,
    isError,
    isIdle,
    isLoading,
    isPolling,
    isSuccess,
    reload,
    error
  } = useDataLoader(keyPage, pageMethod, {
    dataLifetime,
    enabled,
    initialData,
    keepPreviousData,
    needPolling,
    onError,
    onSuccess,
    pollingInterval
  });
  const goToNextPage = useCallback(() => {
    setPage(current => current + 1);
  }, []);
  const goToPreviousPage = useCallback(() => {
    setPage(current => current > 1 ? current - 1 : 1);
  }, []);
  const goToPage = useCallback(newPage => {
    setPage(newPage > 1 ? newPage : 1);
  }, []);
  useEffect(() => {
    setData(current => {
      if (pageData !== current[page]) {
        return {
          ...current,
          [page]: pageData
        };
      }
      return current;
    });
  }, [pageData, page]);
  useEffect(() => {
    setPage(1);
    setData({});
  }, [key]);
  return {
    data,
    error,
    goToNextPage,
    goToPage,
    goToPreviousPage,
    isError,
    isIdle,
    isLoading,
    isPolling,
    isSuccess,
    page,
    pageData,
    reload
  };
};
var usePaginatedDataLoader$1 = usePaginatedDataLoader;

export { usePaginatedDataLoader$1 as default };
